Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code

Unified Diff: include/AdblockPlus/Platform.h

Issue 29527588: Issue 5570 - Make V8 isolate injectable into JsEngine (Closed) Base URL: https://github.com/adblockplus/libadblockplus.git
Patch Set: rebase Created Aug. 25, 2017, 3:08 p.m.
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « include/AdblockPlus/JsEngine.h ('k') | src/JsEngine.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/AdblockPlus/Platform.h
diff --git a/include/AdblockPlus/Platform.h b/include/AdblockPlus/Platform.h
index e07d6f68c64a876e352f6022913392e0355dcb75..7956b2ee10553d719cea9e3be780ba1ac394204c 100644
--- a/include/AdblockPlus/Platform.h
+++ b/include/AdblockPlus/Platform.h
@@ -50,6 +50,7 @@ namespace AdblockPlus
*/
LogSystemPtr CreateDefaultLogSystem();
+ class IV8IsolateProvider;
class JsEngine;
/**
@@ -93,12 +94,14 @@ namespace AdblockPlus
~Platform();
/**
- * Ensures that JsEngine is constructed.
+ * Ensures that JsEngine is constructed. If JsEngine is already present
+ * then the parameters are ignored.
*
* @param appInfo Information about the app, if jsEngine is already present
* then the value is ignored.
*/
- void SetUpJsEngine(const AppInfo& appInfo = AppInfo());
+ void SetUpJsEngine(const AppInfo& appInfo = AppInfo(), std::unique_ptr<IV8IsolateProvider> isolate = nullptr);
/**
* Retrieves the `JsEngine` instance. It calls SetUpJsEngine if JsEngine is
« no previous file with comments | « include/AdblockPlus/JsEngine.h ('k') | src/JsEngine.cpp » ('j') | no next file with comments »
@@ -93,12 +94,14 @@ namespace AdblockPlus
*
- * @param appInfo Information about the app, if jsEngine is already present
- * then the value is ignored.
+ * @param appInfo Information about the app,
+ * @param isolate A provider of v8::Isolate, if the value is nullptr then
+ * a default implementation is used.
*/

Powered by Google App Engine
This is Rietveld